/*
 * Copyright (c) 2018-2028, aokunsang All rights reserved.
 * 我问青山何时老，青山问我几时闲，
 * 不是闲人闲不得，能闲必非等闲人。
 */
package org.springblade.gateway.config;

import lombok.extern.slf4j.Slf4j;
import org.springblade.core.tool.exception.ServiceException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.core.StringRedisTemplate;

import javax.annotation.PostConstruct;

/**
 * redis 启动校验， 如果redis未启动，使系统不能正常启动
 *
 * @author wookvn
 * @datetime 2024/10/08 16:10
 */
@Slf4j
@Configuration
@ConditionalOnProperty(prefix = "spring.redis", value = "checked", havingValue = "true")
public class RedisStartCheckConfigutration {

    @Autowired
    private StringRedisTemplate stringRedisTemplate;

    @PostConstruct
    public void initCheck() {
        try {
            stringRedisTemplate.hasKey("test_key");
            log.info("校验redis实例正常运行");
        } catch (Exception e) {
            throw new ServiceException("校验redis实例未正常运行，请检查|错误描述:" + e.getMessage());
        }
    }
}
