package org.springblade.gateway.filter;

import com.alibaba.fastjson2.JSON;
import lombok.extern.slf4j.Slf4j;
import org.springblade.core.constant.TokenConstant;
import org.springblade.core.jwt.properties.JwtProperties;
import org.springblade.core.tool.utils.WebUtil;
import org.springblade.gateway.properties.BladeSecureProperties;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.gateway.filter.GatewayFilter;
import org.springframework.cloud.gateway.filter.factory.AbstractGatewayFilterFactory;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.stereotype.Component;

import java.nio.charset.StandardCharsets;
import java.util.Base64;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * JWT 内部服务 header过滤器
 */
@Slf4j
@Component
@Deprecated
public class JwtHeaderFilter extends AbstractGatewayFilterFactory<Object> {

    @Autowired
    private JwtProperties jwtProperties;

    @Autowired
    private BladeSecureProperties bladeSecureProperties;

    @Override
    public GatewayFilter apply(Object config) {
        return (exchange, chain) -> {
            ServerHttpRequest request = exchange.getRequest();

            ServerHttpRequest.Builder mutateBuilder = request.mutate();
            String uri = request.getURI().getPath();

            List<String> useJwtKeyList = Stream.of(bladeSecureProperties.getDefaultUseJwtPatterns(), bladeSecureProperties.getUseJwtUrl()).flatMap(List::stream).collect(Collectors.toList());
            // 仅处理登录地址
            if(!useJwtKeyList.stream().anyMatch(urlPattern -> WebUtil.pathUrlMatches(urlPattern, uri, false))){
                return chain.filter(exchange);
            }

            String jwtPropJson = JSON.toJSONString(Map.of("signKey", jwtProperties.getSignKey(), "state", jwtProperties.getState(), "single", jwtProperties.getSingle()));
            String base64JwtPropJson = Base64.getEncoder().encodeToString(jwtPropJson.getBytes(StandardCharsets.UTF_8));
            log.debug("jwtPropJson => {}", base64JwtPropJson);

            mutateBuilder.header(TokenConstant.PLATOMIX_JWT, base64JwtPropJson);
            return chain.filter(exchange.mutate().request(mutateBuilder.build()).build());
        };
    }

    @Override
    public String name() {
        return "JwtHeaderFilter";
    }
}
