package org.springblade.gateway.iam;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpResponse;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import lombok.extern.slf4j.Slf4j;

import java.util.stream.Collectors;

/**
 * 研祥的接口
 */
@Slf4j
public final class IamInterUtil {

    final static String queryOrgByInstIdAndUserIdUrl = "/idm-service/open/inst/org/queryOrgByInstIdAndUserId";
    final static String platformUserRolesUrl = "/inst-authority-service/open/inst/sys/platform-user-roles";

    final static int TIMEOUT = 5000;

    /**
     * 根据租户ID和用户ID查询所属部门ID列表
     * @param domain
     * @param instId
     * @param userId
     * @return
     */
    public static String getDeptIds(String domain, Long instId, Long userId) {
        try{
            String queryParam = String.format("?instId=%s&userId=%s", instId, userId);
            HttpResponse httpResponse = HttpUtil.createGet(StrUtil.removeSuffix(domain, "/") + queryOrgByInstIdAndUserIdUrl + queryParam).setConnectionTimeout(TIMEOUT).setReadTimeout(TIMEOUT).execute();
            String retBody = httpResponse.body();
            JSONObject jsonObject = JSONUtil.parseObj(retBody);
            if(jsonObject.getBool("success")) {
                JSONArray jsonArray = jsonObject.getJSONArray("data");
                //没有值，设置为0。 防止缓存穿透
                return jsonArray.isEmpty() ? "0" : jsonArray.stream().map(JSONObject.class::cast).map(item -> item.getStr("orgId")).collect(Collectors.joining(","));
            }else {
                log.info("getDeptIds|response=" + retBody);
            }
        } catch(Exception e) {
            log.error("调用IAM接口远程获取当前登录用户的部门ID列表失败｜"+e.getMessage(), e);
        }
        return null;
    }

    /**
     * 根据租户ID和用户ID查询所属角色ID列表
     * @param domain
     * @param instId
     * @param userId
     * @return
     */
    public static String getRoleIds(String domain, Long instId, Long userId) {
        try{
            String queryParam = String.format("?instId=%s&userId=%s", instId, userId);
            HttpResponse httpResponse = HttpUtil.createGet(StrUtil.removeSuffix(domain, "/") + platformUserRolesUrl + queryParam).setConnectionTimeout(TIMEOUT).setReadTimeout(TIMEOUT).execute();
            String retBody = httpResponse.body();
            JSONObject jsonObject = JSONUtil.parseObj(retBody);
            if(jsonObject.getBool("success")) {
                JSONArray jsonArray = jsonObject.getJSONArray("data");
                return jsonArray.isEmpty() ? "0" : jsonArray.stream().map(JSONObject.class::cast).map(item -> item.getStr("roleId")).collect(Collectors.joining(","));
            }else {
                log.info("getRoleIds|response=" + retBody);
            }
        } catch(Exception e) {
            log.error("调用IAM接口远程获取当前登录用户的角色ID列表失败｜" + e.getMessage(), e);
        }
        return null;
    }

//    public static void main(String[] args) {
//        System.out.println(getRoleIds("https://iam-inst.9n1m.com/api/", 1747789855280189539L, 1772531785752207362L));
//    }
}