package org.springblade.gateway.iam;

import lombok.Data;
import org.springblade.core.constant.BladeConstant;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.support.Kv;
import org.springblade.core.tool.utils.Base62Util;

import java.util.List;

@Data
public class SignedPrincipal {
    /**
     * 用户编码
     */
    private Long userId;
    /**
     * 登录账号
     */
    private String username;
    /**
     * 手机号
     */
    private String mobile;
    /**
     * 邮箱
     */
    private String email;
    /**
     * 用户类型: 1-注册用户 2-子用户
     */
    private Integer userType;
    /**
     * 显示名称
     */
    private String displayName;
    /**
     * 昵称
     */
    private String nickName;
    /**
     * 等级ID
     */
    private Long userLevel;
    /**
     * 等级名称
     */
    private String userLevelName;
    /**
     * 用户租户编码
     */
    private Long instUserId;
    /**
     * 当前租户编码
     */
    private Long instId;
    /**
     * 当前租户类型： 1=个人租户 2=企业租户
     */
    private Integer instType;
    /**
     * 当前租户名称
     */
    private String enterprise;
    /**
     * 已加入的租户列表
     */
    private List<InstUser> instUsers;
    /**
     * 是否管理员：0=普通用户 1=管理员 2=超级管理员
     */
    private int isAdmin;

    public BladeUser toCurrentUser(int gatewayType) {
        BladeUser bladeUser = new BladeUser();
        bladeUser.setUserId(this.getUserId());
        bladeUser.setAccount(this.getUsername());
        bladeUser.setNickName(this.getNickName());
        bladeUser.setMobile(this.getMobile());
        bladeUser.setUserName(this.getUsername());
        //设置租户ID
        bladeUser.setTenantId(gatewayType == 1 ? BladeConstant.ADMIN_TENANT_ID : Base62Util.encode(this.getInstId()));
        //设置研祥的额外数据
        Kv detail = Kv.create().set("instId", this.getInstId()).set("instType", this.getInstType())
                .set("enterprise", this.getEnterprise()).set("instUserId", this.getInstUserId())
                .set("displayName", this.getDisplayName()).set("userType", this.getUserType())
                .set("userLevel", this.getUserLevel())
                //如果是管理端登录，默认设置isAdmin=2(超级管理员)
                .set("isAdmin", gatewayType == 1 ? 2 : this.getIsAdmin());
        bladeUser.setDetail(detail);
        return bladeUser;
    }
}
