package org.springblade.gateway.properties;

import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.Getter;
import lombok.Setter;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 客户端校验配置
 *
 * @author Chill
 */
@Data
@Configuration
@ConfigurationProperties("blade.secure")
public class BladeSecureProperties {

	/**
	 * 开启鉴权规则
	 */
	private Boolean enabled = true;

	/**
	 * 根据类型，鉴别是哪个环境的网关
	 * 0 - 公司标准产品网关
	 * 1 - 研祥管理端网关
	 * 2 - 研祥用户端网关
	 */
	private Integer type = 0;

	/**
	 * 研祥的deptId和roleId缓存时间(单位：秒)
	 */
	private Integer currUserDeptRoleCacheSecs = 3600;

	/**
	 * 获取部门的iam的接口地址
	 */
	private String iamInst9n1mDomain = "https://91iam-inst.9n1m.com/";

	/**
	 * token解析的AES key
	 */
	private String platomixTokenAesKey = "Z3wlTt5YxCr8QN2AiruWhQ==";

	private String platomixTokenHeader = "PlatomixAuth";

	/**
	 * 鉴权放行请求
	 * <${spring.application.name}, {path:/api, url-list: []}>
	 */
	private final Map<String, PathItemAttribute> skipUrl = new HashMap<>();

	/**
	 * 需要jwt-key的地址路径，包含前缀比如/api，/bi-api等
	 * 该地址一般不需要配置，仅用于生成token的接口地址
	 */
	private final List<String> useJwtUrl = new ArrayList<>();

	/**
	 * 默认放行规则
	 */
	@Setter(AccessLevel.NONE)
	private final List<String> defaultExcludePatterns = new ArrayList<>();

	/**
	 * 默认需要jwt-key的地址规则
	 */
	@Setter(AccessLevel.NONE)
	private final List<String> defaultUseJwtPatterns = new ArrayList<>();

	/**
	 * 白名单URL地址规则
	 */
	@Setter(AccessLevel.NONE)
	private final List<String> defaultWhiteUrlPatterns = new ArrayList<>();
	
	public BladeSecureProperties() {
		//默认接口放行 - 系统组件相关
		this.defaultExcludePatterns.add("/favicon.ico");
		this.defaultExcludePatterns.add("/*/error/**");
		this.defaultExcludePatterns.add("/*/favicon.ico");
		this.defaultExcludePatterns.add("/*/assets/**");
//		this.defaultExcludePatterns.add("/*/doc.html");
		this.defaultExcludePatterns.add("/*/js/**");
		this.defaultExcludePatterns.add("/*/v2/api-docs/**");
		this.defaultExcludePatterns.add("/*/webjars/**");
		this.defaultExcludePatterns.add("/*/swagger-resources/**");
		this.defaultExcludePatterns.add("/*/druid/**");
		this.defaultExcludePatterns.add("/*/doc.html");
		
		//默认接口放行 - 业务相关
		this.defaultExcludePatterns.add("/api/blade-auth/**");
		this.defaultExcludePatterns.add("/api/platomix-auth/**");
		this.defaultExcludePatterns.add("/api/blade-system/menu/routes");
		this.defaultExcludePatterns.add("/api/blade-system/menu/auth-routes");
		this.defaultExcludePatterns.add("/api/blade-system/menu/top-menu");
		this.defaultExcludePatterns.add("/api/blade-system/tenant/info");

		//默认需要jwt-key做序列化等操作
		this.defaultUseJwtPatterns.add("/api/blade-auth/**");
		this.defaultUseJwtPatterns.add("/api/platomix-auth/**");

		//白名单URL地址，不返回错误
		this.defaultWhiteUrlPatterns.add("/favicon.ico");
	}
}
